==> pulumi-azure-native-kotlin-2.19.0.0-sources.jar: com/pulumi/azurenative/machinelearningservices/kotlin/inputs/WorkspaceConnectionPersonalAccessTokenArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.machinelearningservices.kotlin.inputs

import com.pulumi.azurenative.machinelearningservices.inputs.WorkspaceConnectionPersonalAccessTokenArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.String
import kotlin.Suppress
import kotlin.jvm.JvmName

/**
 *
 * @property pat
 */
public data class WorkspaceConnectionPersonalAccessTokenArgs(
    public val pat: Output<String>? = null,
) :
    ConvertibleToJava<com.pulumi.azurenative.machinelearningservices.inputs.WorkspaceConnectionPersonalAccessTokenArgs> {
    override fun toJava():
        com.pulumi.azurenative.machinelearningservices.inputs.WorkspaceConnectionPersonalAccessTokenArgs =
        com.pulumi.azurenative.machinelearningservices.inputs.WorkspaceConnectionPersonalAccessTokenArgs.builder()
            .pat(pat?.applyValue({ args0 -> args0 })).build()
}

/**
 * Builder for [WorkspaceConnectionPersonalAccessTokenArgs].
 */
@PulumiTagMarker
public class WorkspaceConnectionPersonalAccessTokenArgsBuilder internal constructor() {
    private var pat: Output<String>? = null

    /**
     * @param value
     */
    @JvmName("gkwcqcoogmfiyrna")
    public suspend fun pat(`value`: Output<String>) {
        this.pat = value
    }

    /**
     * @param value
     */
    @JvmName("enqhpjaaylicpwjq")
    public suspend fun pat(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.pat = mapped
    }

    internal fun build(): WorkspaceConnectionPersonalAccessTokenArgs =
        WorkspaceConnectionPersonalAccessTokenArgs(
            pat = pat,
        )
}

==> pulumi-azure-native-kotlin-2.28.0.0-sources.jar: com/pulumi/azurenative/machinelearningservices/kotlin/inputs/WorkspaceConnectionPersonalAccessTokenArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.machinelearningservices.kotlin.inputs

import com.pulumi.azurenative.machinelearningservices.inputs.WorkspaceConnectionPersonalAccessTokenArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.String
import kotlin.Suppress
import kotlin.jvm.JvmName

/**
 *
 * @property pat
 */
public data class WorkspaceConnectionPersonalAccessTokenArgs(
    public val pat: Output<String>? = null,
) :
    ConvertibleToJava<com.pulumi.azurenative.machinelearningservices.inputs.WorkspaceConnectionPersonalAccessTokenArgs> {
    override fun toJava():
        com.pulumi.azurenative.machinelearningservices.inputs.WorkspaceConnectionPersonalAccessTokenArgs =
        com.pulumi.azurenative.machinelearningservices.inputs.WorkspaceConnectionPersonalAccessTokenArgs.builder()
            .pat(pat?.applyValue({ args0 -> args0 })).build()
}

/**
 * Builder for [WorkspaceConnectionPersonalAccessTokenArgs].
 */
@PulumiTagMarker
public class WorkspaceConnectionPersonalAccessTokenArgsBuilder internal constructor() {
    private var pat: Output<String>? = null

    /**
     * @param value
     */
    @JvmName("jsqhelljhmjihcif")
    public suspend fun pat(`value`: Output<String>) {
        this.pat = value
    }

    /**
     * @param value
     */
    @JvmName("xpldpdqcjwwpjbfq")
    public suspend fun pat(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.pat = mapped
    }

    internal fun build(): WorkspaceConnectionPersonalAccessTokenArgs =
        WorkspaceConnectionPersonalAccessTokenArgs(
            pat = pat,
        )
}
